/*
 * MIT License
 *
 * Copyright (c) 2019 Alexey Edelev <semlanik@gmail.com>
 *
 * This file is part of NeuralNetwork project https://git.semlanik.org/semlanik/NeuralNetwork
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this
 * software and associated documentation files (the "Software"), to deal in the Software
 * without restriction, including without limitation the rights to use, copy, modify,
 * merge, publish, distribute, sublicense, and/or sell copies of the Software, and
 * to permit persons to whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies
 * or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#pragma once

#include <QObject>
#include "abstractdense.h"
#include "dense.h"

class ValueIndicatorDense;
class ValueIndicator : public QObject
{
    Q_OBJECT
    Q_PROPERTY(qreal value READ value CONSTANT)
public:
    ValueIndicator(ValueIndicatorDense *dense);
    qreal value() const;

public slots:
    void setValue(qreal value)
    {
        m_value = value;
    }
private:
    qreal m_value;
    ValueIndicatorDense *m_dense;
};

class ValueIndicatorDense : public AbstractDense<QList<ValueIndicator*>> {
public:
    ValueIndicatorDense() = default;
    virtual ~ValueIndicatorDense();
    ValueIndicatorDense(int rows, int columns, const QList<ValueIndicator*>& data);
    void updateValues(const Dense& dense);

    double min() const {
        return m_min;
    }

    double max() const {
        return m_max;
    }

private:
    double m_max;
    double m_min;
};
