/*
 * MIT License
 *
 * Copyright (c) 2019 Alexey Edelev <semlanik@gmail.com>
 *
 * This file is part of NeuralNetwork project https://git.semlanik.org/semlanik/NeuralNetwork
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this
 * software and associated documentation files (the "Software"), to deal in the Software
 * without restriction, including without limitation the rights to use, copy, modify,
 * merge, publish, distribute, sublicense, and/or sell copies of the Software, and
 * to permit persons to whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies
 * or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

import QtQuick 2.11
import QtQuick.Window 2.11
import QtQuick.Controls 1.4

ApplicationWindow {
    id: root
    visible: true
    width: 1024
    height: 768
    MouseArea {
        id: drawingArea
        width: 28*20
        height: 28*20
        onPositionChanged: {
            root.contentItem.child
            mouse.x
            mouse.y
        }
    }
    Repeater {
        model: 784
        Rectangle {
            id: tile
            width: 20
            height: 20
            color: "black"
            x: 20*Math.floor(model.index/28)
            y: 20*(model.index%28)
            border.width: 1
            border.color: "white"
            Connections {
                target: drawingArea
                onPositionChanged: {
                    var centerX = tile.x + tile.width/2
                    var centerY = tile.y + tile.height/2
                    var diffX = mouse.x - centerX
                    var diffY = mouse.y - centerY
                    var dense = Math.sqrt(diffX * diffX + diffY * diffY)
                    if(dense < 20) {
                        tile.color = Qt.rgba(color.r + (20-dense)/20, color.g + (20-dense)/20, color.b + (20-dense)/20, 1.0)
                    }
                }
            }

            Connections {
                target: clearButton
                onClicked: {
                    tile.color = "black"
                }
            }
        }
    }

    Column {
        anchors.right: parent.right
        Button {
            id: clearButton
            text: "Clear"
        }
    }
}
